@@ -27,6 +27,7 @@
 #include "goaprovider-priv.h"
 #include "goaflickrprovider.h"
 #include "goaobjectskeletonutils.h"
+#include "goasouplogger.h"
 
 struct _GoaFlickrProvider
 {
@@ -82,25 +83,29 @@ get_consumer_secret (GoaOAuthProvider *oauth_provider)
 static const gchar *
 get_request_uri (GoaOAuthProvider *oauth_provider)
 {
-  return "https://m.flickr.com/services/oauth/request_token";
+  return "https://www.flickr.com/services/oauth/request_token";
 }
 
 static const gchar *
 get_authorization_uri (GoaOAuthProvider *oauth_provider)
 {
-  return "https://m.flickr.com/services/oauth/authorize";
+  return "https://www.flickr.com/services/oauth/authorize";
 }
 
 static const gchar *
 get_token_uri (GoaOAuthProvider *oauth_provider)
 {
-  return "https://m.flickr.com/services/oauth/access_token";
+  return "https://www.flickr.com/services/oauth/access_token";
 }
 
 static const gchar *
 get_callback_uri (GoaOAuthProvider *oauth_provider)
 {
-  return "https://www.gnome.org/goa-1.0/oauth";
+  /* Should match the URI specified in the Flickr App
+   * Garden in order to detect when the user denied access via
+   * the OAuth1 web page.
+   */
+  return "https://www.gnome.org/";
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
@@ -118,6 +123,7 @@ get_identity_sync (GoaOAuthProvider  *oauth_provider,
   RestProxyCall *call = NULL;
   JsonParser *parser = NULL;
   JsonObject *json_object;
+  SoupLogger *logger = NULL;
   gchar *ret = NULL;
   gchar *id = NULL;
   gchar *presentation_identity = NULL;
@@ -130,6 +136,9 @@ get_identity_sync (GoaOAuthProvider  *oauth_provider,
                                       access_token_secret,
                                       "https://api.flickr.com/services/rest",
                                       FALSE);
+  logger = goa_soup_logger_new (SOUP_LOGGER_LOG_BODY, -1);
+  rest_proxy_add_soup_feature (proxy, SOUP_SESSION_FEATURE (logger));
+
   call = rest_proxy_new_call (proxy);
   rest_proxy_call_add_param (call, "method", "flickr.test.login");
   rest_proxy_call_add_param (call, "format", "json");
@@ -167,8 +176,7 @@ get_identity_sync (GoaOAuthProvider  *oauth_provider,
     }
 
   json_object = json_node_get_object (json_parser_get_root (parser));
-  json_object = json_object_get_object_member (json_object, "user");
-  if (json_object == NULL)
+  if (!json_object_has_member (json_object, "user"))
     {
       g_warning ("Did not find user in JSON data");
       g_set_error (error,
@@ -177,8 +185,9 @@ get_identity_sync (GoaOAuthProvider  *oauth_provider,
                    _("Could not parse response"));
       goto out;
     }
-  id = g_strdup (json_object_get_string_member (json_object, "id"));
-  if (id == NULL)
+
+  json_object = json_object_get_object_member (json_object, "user");
+  if (!json_object_has_member (json_object, "id"))
     {
       g_warning ("Did not find user.id in JSON data");
       g_set_error (error,
@@ -187,8 +196,7 @@ get_identity_sync (GoaOAuthProvider  *oauth_provider,
                    _("Could not parse response"));
       goto out;
     }
-  json_object = json_object_get_object_member (json_object, "username");
-  if (json_object == NULL)
+  if (!json_object_has_member (json_object, "username"))
     {
       g_warning ("Did not find user.username in JSON data");
       g_set_error (error,
@@ -197,8 +205,11 @@ get_identity_sync (GoaOAuthProvider  *oauth_provider,
                    _("Could not parse response"));
       goto out;
     }
-  presentation_identity = g_strdup (json_object_get_string_member (json_object, "_content"));
-  if (presentation_identity == NULL)
+
+  id = g_strdup (json_object_get_string_member (json_object, "id"));
+
+  json_object = json_object_get_object_member (json_object, "username");
+  if (!json_object_has_member (json_object, "_content"))
     {
       g_warning ("Did not find user.username._content in JSON data");
       g_set_error (error,
@@ -208,6 +219,8 @@ get_identity_sync (GoaOAuthProvider  *oauth_provider,
       goto out;
     }
 
+  presentation_identity = g_strdup (json_object_get_string_member (json_object, "_content"));
+
   ret = id;
   id = NULL;
   if (out_presentation_identity != NULL)
@@ -221,6 +234,7 @@ get_identity_sync (GoaOAuthProvider  *oauth_provider,
   g_clear_error (&identity_error);
   g_clear_object (&call);
   g_clear_object (&proxy);
+  g_clear_object (&logger);
   g_free (id);
   g_free (presentation_identity);
   return ret;
