@@ -27,6 +27,7 @@
 #include "goaoauth2provider.h"
 #include "goagoogleprovider.h"
 #include "goaobjectskeletonutils.h"
+#include "goarestproxy.h"
 
 struct _GoaGoogleProvider
 {
@@ -175,7 +176,7 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
 
   /* TODO: cancellable */
 
-  proxy = rest_proxy_new ("https://www.googleapis.com/oauth2/v2/userinfo", FALSE);
+  proxy = goa_rest_proxy_new ("https://www.googleapis.com/oauth2/v2/userinfo", FALSE);
   call = rest_proxy_new_call (proxy);
   rest_proxy_call_set_method (call, "GET");
   rest_proxy_call_add_param (call, "access_token", access_token);
@@ -211,8 +212,7 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
     }
 
   json_object = json_node_get_object (json_parser_get_root (parser));
-  email = g_strdup (json_object_get_string_member (json_object, "email"));
-  if (email == NULL)
+  if (!json_object_has_member (json_object, "email"))
     {
       g_warning ("Did not find email in JSON data");
       g_set_error (error,
@@ -222,6 +222,7 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
       goto out;
     }
 
+  email = g_strdup (json_object_get_string_member (json_object, "email"));
 
   ret = email;
   email = NULL;
